==> 0.11.4.tar.gz: lib/widgets/senior_switch.dart <==
import 'package:flutter/cupertino.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum SeniorSwitchLabelPosition {
  left, right
}

class SeniorSwitchTheme {
  SeniorSwitchTheme._();

  static Color getSwitchActiveColor() {
    return SeniorColors.primaryColor;
  }

  static Color getSwitchTrackColor() {
    return SeniorColors.secondaryColor600;
  }

  static Color getSwitchTextColor({
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorSwitch extends StatelessWidget {
  final String title;
  final bool value;
  final Function(bool?) onChanged;
  final bool disabled;
  final bool fullLenght;
  final SeniorSwitchLabelPosition labelPosition;

  const SeniorSwitch({
    Key? key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
    this.fullLenght = false,
    this.labelPosition = SeniorSwitchLabelPosition.left,
  }) : super(key: key);

  Widget buildSwitch() {
    return Container(
      margin: EdgeInsets.only(right: 8.0),
      child: Transform.scale(
        scale: 0.7, 
        child: CupertinoSwitch(
          value: this.value,
          onChanged: !this.disabled
            ? this.onChanged
            : null,
          activeColor: SeniorSwitchTheme.getSwitchActiveColor(),
          trackColor: SeniorSwitchTheme.getSwitchTrackColor(),
        ),
      ),
    );
  }

  Widget buildLabel() {
    return Flexible(
      child: Text(
        this.title,
        style: SeniorTypography.text(color: SeniorSwitchTheme.getSwitchTextColor(isDisabled: this.disabled)),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: this.fullLenght
        ? MainAxisAlignment.spaceBetween
        : MainAxisAlignment.start,
      children: this.labelPosition == SeniorSwitchLabelPosition.left
        ? [buildLabel(), buildSwitch()]
        : [buildSwitch(), buildLabel()],
    );
  }
}

==> 0.13.1.tar.gz: lib/widgets/senior_switch.dart <==
import 'package:flutter/cupertino.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum SeniorSwitchLabelPosition {
  left, right
}

class SeniorSwitchTheme {
  SeniorSwitchTheme._();

  static Color getSwitchActiveColor() {
    return SeniorColors.primaryColor;
  }

  static Color getSwitchTrackColor() {
    return SeniorColors.secondaryColor600;
  }

  static Color getSwitchTextColor({
    required bool isDisabled
  }) {
    if(!isDisabled) {
      return SeniorColors.neutralColor900;
    }
    return SeniorColors.secondaryColor300;
  }
}

class SeniorSwitch extends StatelessWidget {
  final String title;
  final bool value;
  final Function(bool?) onChanged;
  final bool disabled;
  final bool fullLenght;
  final SeniorSwitchLabelPosition labelPosition;

  const SeniorSwitch({
    Key? key,
    required this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
    this.fullLenght = false,
    this.labelPosition = SeniorSwitchLabelPosition.left,
  }) : super(key: key);

  Widget buildSwitch() {
    return Container(
      margin: EdgeInsets.only(right: 8.0),
      child: Transform.scale(
        scale: 0.7, 
        child: CupertinoSwitch(
          value: value,
          onChanged: !disabled
            ? onChanged
            : null,
          activeColor: SeniorSwitchTheme.getSwitchActiveColor(),
          trackColor: SeniorSwitchTheme.getSwitchTrackColor(),
        ),
      ),
    );
  }

  Widget buildLabel() {
    return Flexible(
      child: Text(
        title,
        style: SeniorTypography.text(
          color: SeniorSwitchTheme.getSwitchTextColor(
            isDisabled: disabled,
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: fullLenght
        ? MainAxisAlignment.spaceBetween
        : MainAxisAlignment.start,
      children: labelPosition == SeniorSwitchLabelPosition.left
        ? [buildLabel(), buildSwitch()]
        : [buildSwitch(), buildLabel()],
    );
  }
}
